@@ -509,8 +509,23 @@ func (m *pageMap) forEachResourceInPage(
 			// A page key points to the logical path of a page, which when sourced from the filesystem
 			// may represent a directory (bundles) or a single content file (e.g. p1.md).
 			// So, to avoid any overlapping ambiguity, we start looking from the owning directory.
-			ownerKey, _ := m.treePages.LongestPrefixAll(path.Dir(resourceKey))
-			if ownerKey != keyPage {
+			s := resourceKey
+
+			for {
+				s = path.Dir(s)
+				ownerKey, found := m.treePages.LongestPrefixAll(s)
+				if !found {
+					return true, nil
+				}
+				if ownerKey == keyPage {
+					break
+				}
+
+				if s != ownerKey && strings.HasPrefix(s, ownerKey) {
+					// Keep looking
+					continue
+				}
+
 				// Stop walking downwards, someone else owns this resource.
 				rw.SkipPrefix(ownerKey + "/")
 				return false, nil
@@ -1274,7 +1289,7 @@ func (h *HugoSites) resolveAndResetDependententPageOutputs(ctx context.Context,
 
 		po.renderState = 0
 		po.p.resourcesPublishInit = &sync.Once{}
-		if r == identity.FinderFoundOneOfMany {
+		if r == identity.FinderFoundOneOfMany || po.f.Name == output.HTTPStatusHTMLFormat.Name {
 			// Will force a re-render even in fast render mode.
 			po.renderOnce = false
 		}
@@ -1310,6 +1325,7 @@ func (h *HugoSites) resolveAndResetDependententPageOutputs(ctx context.Context,
 				if !po.isRendered() {
 					continue
 				}
+
 				for _, id := range changes {
 					checkedCounter.Add(1)
 					if r := depsFinder.Contains(id, po.dependencyManagerOutput, 50); r > identity.FinderFoundOneOfManyRepetition {
