@@ -16,13 +16,18 @@ package render
 import (
 	"bytes"
 	"math/bits"
+	"strings"
 	"sync"
 
+	bp "github.com/gohugoio/hugo/bufferpool"
+
 	htext "github.com/gohugoio/hugo/common/text"
+	"github.com/gohugoio/hugo/tpl"
 
 	"github.com/gohugoio/hugo/markup/converter"
 	"github.com/gohugoio/hugo/markup/converter/hooks"
 	"github.com/yuin/goldmark/ast"
+	"github.com/yuin/goldmark/util"
 )
 
 type BufWriter struct {
@@ -258,3 +263,34 @@ func (c *hookBase) Position() htext.Position {
 func (c *hookBase) PositionerSourceTarget() []byte {
 	return c.getSourceSample()
 }
+
+// TextPlain returns a plain text representation of the given node.
+// This will resolve any lefover HTML entities. This will typically be
+// entities inserted by e.g. the typographer extension.
+// Goldmark's Node.Text was deprecated in 1.7.8.
+func TextPlain(n ast.Node, source []byte) string {
+	buf := bp.GetBuffer()
+	defer bp.PutBuffer(buf)
+
+	for c := n.FirstChild(); c != nil; c = c.NextSibling() {
+		textPlainTo(c, source, buf)
+	}
+	return string(util.ResolveEntityNames(buf.Bytes()))
+}
+
+func textPlainTo(c ast.Node, source []byte, buf *bytes.Buffer) {
+	if c == nil {
+		return
+	}
+	switch c := c.(type) {
+	case *ast.RawHTML:
+		s := strings.TrimSpace(tpl.StripHTML(string(c.Segments.Value(source))))
+		buf.WriteString(s)
+	case *ast.String:
+		buf.Write(c.Value)
+	case *ast.Text:
+		buf.Write(c.Segment.Value(source))
+	default:
+		textPlainTo(c.FirstChild(), source, buf)
+	}
+}
